#========================================================================================
# package      DE_EPAGES::AmazonPayments::t::unit::MapAmazonAddress
# base         DE_EPAGES::Database::API::Test
#----------------------------------------------------------------------------------------
# description  unit test for mapping address from Amazon Payments
#========================================================================================
package DE_EPAGES::AmazonPayments::t::unit::MapAmazonAddress;

use base DE_EPAGES::Database::API::Test;
use DE_EPAGES::AmazonPayments::API::DTO::AddressInfo;
use DE_EPAGES::AmazonPayments::API::Payment qw ( ConvertAmazonAddress );
use DE_EPAGES::Test::Mock::Mockify;
use DE_EPAGES::Test::Mock::MockifyEpagesObject;
use Test::More;

use strict;

sub test {
    my $self = shift;

    $self->test_uk_convertAmazonAddress();
    $self->test_uk_convertAmazonAddress_addressLine1_missing();
    $self->test_uk_convertAmazonAddress_addressLine2_missing();

    $self->test_de_convertAmazonAddress();
    $self->test_de_convertAmazonAddress_addressLine1_missing();
    $self->test_de_convertAmazonAddress_addressLine2_missing();
    done_testing();
}
#----------------------------------------------------------------------------------------
sub test_uk_convertAmazonAddress {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $UKCountryID = '826';
    my $AmazonAddr = $self->_uk_amazon_fields();
    my $Mockify  = DE_EPAGES::Test::Mock::MockifyEpagesObject->new('DE_EPAGES::AmazonPayments::API::Object::LineItemPaymentAmazonPayments', {
                    'Alias' => 'MockLineItem', 'TransID' => 'S02-3029547-9718378'});
    my $hAddress = ConvertAmazonAddress( $Mockify->getMockObject(), $AmazonAddr );
    is($hAddress->{'FirstName'}, $AmazonAddr->{'firstName'}, "$SubTestName - Test if firstName is mapped correctly");
    is($hAddress->{'LastName'}, $AmazonAddr->{'lastName'}, "$SubTestName - Test if lastName is mapped correctly");
    is($hAddress->{'Street'}, $AmazonAddr->{'addressLine1'}, "$SubTestName - Street should be mapped with amazon addressLine1");
    is($hAddress->{'Street2'}, $AmazonAddr->{'addressLine2'}, "$SubTestName - Street2 should be mapped with amazon addressLine2");
    is($hAddress->{'AddressExtension'}, $AmazonAddr->{'addressLine3'}, "$SubTestName - Test if addressLine3 is mapped correctly");
    is($hAddress->{'City'}, $AmazonAddr->{'city'}, "$SubTestName - Test if city is mapped correctly");
    is($hAddress->{'State'}, $AmazonAddr->{'stateOrRegion'}, "$SubTestName - Test if stateOrRegion is mapped correctly");
    is($hAddress->{'Zipcode'}, $AmazonAddr->{'postalCode'}, "$SubTestName - Test if postalCode is mapped correctly");
    is($hAddress->{'CountryID'}, $UKCountryID, "$SubTestName - Test if countryCode is mapped correctly");
}

sub test_uk_convertAmazonAddress_addressLine1_missing {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $UKCountryID = '826';
    my $AmazonAddr = $self->_uk_amazon_fields_missing_addressLine1();
    my $Mockify  = DE_EPAGES::Test::Mock::MockifyEpagesObject->new('DE_EPAGES::AmazonPayments::API::Object::LineItemPaymentAmazonPayments', {
                    'Alias' => 'MockLineItem', 'TransID' => 'S02-3029547-9718378'});
    my $hAddress = ConvertAmazonAddress( $Mockify->getMockObject(), $AmazonAddr );

    is($hAddress->{'FirstName'}, $AmazonAddr->{'firstName'}, "$SubTestName - Test if firstName is mapped correctly");
    is($hAddress->{'LastName'}, $AmazonAddr->{'lastName'}, "$SubTestName - Test if lastName is mapped correctly");
    is($hAddress->{'Street'}, $AmazonAddr->{'addressLine1'}, "$SubTestName - Street should be mapped with amazon addressLine1");
    is($hAddress->{'Street2'}, $AmazonAddr->{'addressLine2'}, "$SubTestName - Street2 should be mapped with amazon addressLine2");
    is($hAddress->{'AddressExtension'}, $AmazonAddr->{'addressLine3'}, "$SubTestName - Test if addressLine3 is mapped correctly");
    is($hAddress->{'City'}, $AmazonAddr->{'city'}, "$SubTestName - Test if city is mapped correctly");
    is($hAddress->{'State'}, $AmazonAddr->{'stateOrRegion'}, "$SubTestName - Test if stateOrRegion is mapped correctly");
    is($hAddress->{'Zipcode'}, $AmazonAddr->{'postalCode'}, "$SubTestName - Test if postalCode is mapped correctly");
    is($hAddress->{'CountryID'}, $UKCountryID, "$SubTestName - Test if countryCode is mapped correctly");
}

sub test_uk_convertAmazonAddress_addressLine2_missing {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $UKCountryID = '826';
    my $AmazonAddr = $self->_uk_amazon_fields_missing_addressLine2();
    my $Mockify  = DE_EPAGES::Test::Mock::MockifyEpagesObject->new('DE_EPAGES::AmazonPayments::API::Object::LineItemPaymentAmazonPayments', {
                    'Alias' => 'MockLineItem', 'TransID' => 'S02-3029547-9718378'});
    my $hAddress = ConvertAmazonAddress( $Mockify->getMockObject(), $AmazonAddr );

    is($hAddress->{'FirstName'}, $AmazonAddr->{'firstName'}, "$SubTestName - Test if firstName is mapped correctly");
    is($hAddress->{'LastName'}, $AmazonAddr->{'lastName'}, "$SubTestName - Test if lastName is mapped correctly");
    is($hAddress->{'Street'}, $AmazonAddr->{'addressLine1'}, "$SubTestName - Street should be mapped with amazon addressLine1 since amazon addressLine2 is not present");
    is($hAddress->{'Street2'}, undef, "$SubTestName - Test if Street2 should be undef once Street is mapped with amazon addressLine1 and amazon addressLine2 is not present");
    is($hAddress->{'AddressExtension'}, $AmazonAddr->{'addressLine3'}, "$SubTestName - Test if addressLine3 is mapped correctly");
    is($hAddress->{'City'}, $AmazonAddr->{'city'}, "$SubTestName - Test if city is mapped correctly");
    is($hAddress->{'State'}, $AmazonAddr->{'stateOrRegion'}, "$SubTestName - Test if stateOrRegion is mapped correctly");
    is($hAddress->{'Zipcode'}, $AmazonAddr->{'postalCode'}, "$SubTestName - Test if postalCode is mapped correctly");
    is($hAddress->{'CountryID'}, $UKCountryID, "$SubTestName - Test if countryCode is mapped correctly");
}

sub test_de_convertAmazonAddress {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $DECountryID = '276';
    my $AmazonAddr = $self->_de_amazon_fields();
    my $Mockify  = DE_EPAGES::Test::Mock::MockifyEpagesObject->new('DE_EPAGES::AmazonPayments::API::Object::LineItemPaymentAmazonPayments', {
                    'Alias' => 'MockLineItem', 'TransID' => 'S02-3029547-9718378'});
    my $hAddress = ConvertAmazonAddress( $Mockify->getMockObject(), $AmazonAddr );
    is($hAddress->{'FirstName'}, $AmazonAddr->{'firstName'}, "$SubTestName - Test if firstName is mapped correctly");
    is($hAddress->{'LastName'}, $AmazonAddr->{'lastName'}, "$SubTestName - Test if lastName is mapped correctly");
    is($hAddress->{'Street'}, $AmazonAddr->{'addressLine2'}, "$SubTestName - Street should be mapped with amazon addressLine2");
    is($hAddress->{'Street2'}, $AmazonAddr->{'addressLine1'}, "$SubTestName - Street2 should be mapped with amazon addressLine1");
    is($hAddress->{'AddressExtension'}, $AmazonAddr->{'addressLine3'}, "$SubTestName - Test if addressLine3 is mapped correctly");
    is($hAddress->{'City'}, $AmazonAddr->{'city'}, "$SubTestName - Test if city is mapped correctly");
    is($hAddress->{'State'}, $AmazonAddr->{'stateOrRegion'}, "$SubTestName - Test if stateOrRegion is mapped correctly");
    is($hAddress->{'Zipcode'}, $AmazonAddr->{'postalCode'}, "$SubTestName - Test if postalCode is mapped correctly");
    is($hAddress->{'CountryID'}, $DECountryID, "$SubTestName - Test if countryCode is mapped correctly");
}

sub test_de_convertAmazonAddress_addressLine1_missing {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $DECountryID = '276';
    my $AmazonAddr = $self->_de_amazon_fields_missing_addressLine1();
    my $Mockify  = DE_EPAGES::Test::Mock::MockifyEpagesObject->new('DE_EPAGES::AmazonPayments::API::Object::LineItemPaymentAmazonPayments', {
                    'Alias' => 'MockLineItem', 'TransID' => 'S02-3029547-9718378'});
    my $hAddress = ConvertAmazonAddress( $Mockify->getMockObject(), $AmazonAddr );

    is($hAddress->{'FirstName'}, $AmazonAddr->{'firstName'}, "$SubTestName - Test if firstName is mapped correctly");
    is($hAddress->{'LastName'}, $AmazonAddr->{'lastName'}, "$SubTestName - Test if lastName is mapped correctly");
    is($hAddress->{'Street'}, $AmazonAddr->{'addressLine2'}, "$SubTestName - Street should be mapped with amazon addressLine2");
    is($hAddress->{'Street2'}, $AmazonAddr->{'addressLine1'}, "$SubTestName - Street2 should be mapped with amazon addressLine1");
    is($hAddress->{'AddressExtension'}, $AmazonAddr->{'addressLine3'}, "$SubTestName - Test if addressLine3 is mapped correctly");
    is($hAddress->{'City'}, $AmazonAddr->{'city'}, "$SubTestName - Test if city is mapped correctly");
    is($hAddress->{'State'}, $AmazonAddr->{'stateOrRegion'}, "$SubTestName - Test if stateOrRegion is mapped correctly");
    is($hAddress->{'Zipcode'}, $AmazonAddr->{'postalCode'}, "$SubTestName - Test if postalCode is mapped correctly");
    is($hAddress->{'CountryID'}, $DECountryID, "$SubTestName - Test if countryCode is mapped correctly");
}

sub test_de_convertAmazonAddress_addressLine2_missing {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $DECountryID = '276';
    my $AmazonAddr = $self->_de_amazon_fields_missing_addressLine2();
    my $Mockify  = DE_EPAGES::Test::Mock::MockifyEpagesObject->new('DE_EPAGES::AmazonPayments::API::Object::LineItemPaymentAmazonPayments', {
                    'Alias' => 'MockLineItem', 'TransID' => 'S02-3029547-9718378'});
    my $hAddress = ConvertAmazonAddress( $Mockify->getMockObject(), $AmazonAddr );

    is($hAddress->{'FirstName'}, $AmazonAddr->{'firstName'}, "$SubTestName - Test if firstName is mapped correctly");
    is($hAddress->{'LastName'}, $AmazonAddr->{'lastName'}, "$SubTestName - Test if lastName is mapped correctly");
    is($hAddress->{'Street'}, $AmazonAddr->{'addressLine1'}, "$SubTestName - Street should be mapped with amazon addressLine1 since amazon addressLine2 is not present");
    is($hAddress->{'Street2'}, undef, "$SubTestName - Test if Street2 should be undef once Street is mapped with amazon addressLine1 and amazon addressLine2 is not present");
    is($hAddress->{'AddressExtension'}, $AmazonAddr->{'addressLine3'}, "$SubTestName - Test if addressLine3 is mapped correctly");
    is($hAddress->{'City'}, $AmazonAddr->{'city'}, "$SubTestName - Test if city is mapped correctly");
    is($hAddress->{'State'}, $AmazonAddr->{'stateOrRegion'}, "$SubTestName - Test if stateOrRegion is mapped correctly");
    is($hAddress->{'Zipcode'}, $AmazonAddr->{'postalCode'}, "$SubTestName - Test if postalCode is mapped correctly");
    is($hAddress->{'CountryID'}, $DECountryID, "$SubTestName - Test if countryCode is mapped correctly");
}
#----------------------------------------------------------------------------------------
# helpers
#----------------------------------------------------------------------------------------
sub _uk_amazon_fields {
    return DE_EPAGES::AmazonPayments::API::DTO::AddressInfo->new({ 'firstName' => 'Max', 'lastName' => 'Mustermann',
             'addressLine1' => 'A', 'addressLine2' => 'B',
             'addressLine3' => 'C', 'city' => 'London',
             'stateOrRegion' => 'E', 'postalCode' => 'SE1 2BY',
             'countryCode' => 'GB', 'phone' => '1234567890'});
}
sub _uk_amazon_fields_missing_addressLine1 {
    return DE_EPAGES::AmazonPayments::API::DTO::AddressInfo->new({ 'firstName' => 'Max', 'lastName' => 'Mustermann',
             'addressLine2' => 'B',
             'addressLine3' => 'C', 'city' => 'London',
             'stateOrRegion' => 'E', 'postalCode' => 'SE1 2BY',
             'countryCode' => 'GB', 'phone' => '1234567890'});
}
sub _uk_amazon_fields_missing_addressLine2 {
    return DE_EPAGES::AmazonPayments::API::DTO::AddressInfo->new({ 'firstName' => 'Max', 'lastName' => 'Mustermann',
             'addressLine1' => 'A',
             'addressLine3' => 'C', 'city' => 'London',
             'stateOrRegion' => 'E', 'postalCode' => 'SE1 2BY',
             'countryCode' => 'GB', 'phone' => '1234567890'});
}

sub _de_amazon_fields {
    return DE_EPAGES::AmazonPayments::API::DTO::AddressInfo->new({ 'firstName' => 'Max', 'lastName' => 'Mustermann',
             'addressLine1' => 'A', 'addressLine2' => 'B',
             'addressLine3' => 'C', 'city' => 'London',
             'stateOrRegion' => 'E', 'postalCode' => 'SE1 2BY',
             'countryCode' => 'DE', 'phone' => '1234567890'});
}
sub _de_amazon_fields_missing_addressLine1 {
    return DE_EPAGES::AmazonPayments::API::DTO::AddressInfo->new({ 'firstName' => 'Max', 'lastName' => 'Mustermann',
             'addressLine2' => 'B',
             'addressLine3' => 'C', 'city' => 'London',
             'stateOrRegion' => 'E', 'postalCode' => 'SE1 2BY',
             'countryCode' => 'DE', 'phone' => '1234567890'});
}
sub _de_amazon_fields_missing_addressLine2 {
    return DE_EPAGES::AmazonPayments::API::DTO::AddressInfo->new({ 'firstName' => 'Max', 'lastName' => 'Mustermann',
             'addressLine1' => 'A',
             'addressLine3' => 'C', 'city' => 'London',
             'stateOrRegion' => 'E', 'postalCode' => 'SE1 2BY',
             'countryCode' => 'DE', 'phone' => '1234567890'});
}

__PACKAGE__->runScript();