#========================================================================================
# package      DE_EPAGES::Order::t::LastUpdateProfile
#----------------------------------------------------------------------------------------
# description  Test LastUpdate profiles for orders
#========================================================================================
package DE_EPAGES::Order::t::LastUpdateProfile;
use base DE_EPAGES::Shop::API::Test;

use strict;
use Test::More tests => 11;

use DE_EPAGES::Core::API::PerlTools qw ( GetCurrentDateTime AddDuration );
use DE_EPAGES::Object::API::Factory qw (LoadClassByAlias);
use DE_EPAGES::Object::API::XML::ObjectImportHandler qw (ImportObjects);

sub _initProfile {
    my $self = shift;
    my ($ProfileName) = @_;

    my $Profile = LoadClassByAlias('CustomerOrder')->lastUpdateProfile($ProfileName);
    my $Shop = $self->shop;
    my $Now = GetCurrentDateTime();

    $Shop->clearUpdatedObjects( $Profile, AddDuration($Now, 'seconds', 2) );
    my $Iterator = $Shop->getUpdatedObjects($Profile, $Now);
    is $Iterator->count, 0, "no $ProfileName updates yet";

    return $Profile;
}


sub _cAssertItemCount {
    my $self = shift;
    my ($Count, $Profile, $Now) = @_;
    my $Shop = $self->shop;
    my $Iterator = $Shop->getUpdatedObjects($Profile, $Now);
    is $Iterator->count, $Count, 'content updates recorded' or do {
        while (my $hUpdate = $Iterator->next) {
           note 'Updated: (' . $hUpdate->{'Object'}->id . ') ' . $hUpdate->{'Object'}->get('RelativePath');
        }
    };
}


sub testStatus {
    my $self = shift;
    my $Shop = $self->shop;
    my $Now = GetCurrentDateTime();

    # test set
    my $Profile = $self->_initProfile('Status');
    $Shop->path('TestCustomer/Orders/1234-5678')->set({'ShippedOn' => $Now });
    $self->_cAssertItemCount(1, $Profile, $Now);

    # test if status is set to same value.
    $Profile = $self->_initProfile('Status');
    $Shop->path('TestCustomer/Orders/1234-5678')->set({'ShippedOn' => $Now });
    $Shop->path('TestCustomer/Orders/1234-5678')->set({'ShippedOn' => $Now });
    $self->_cAssertItemCount(0, $Profile, $Now);

    # test unset
    $Profile = $self->_initProfile('Status');
    $Shop->path('TestCustomer/Orders/1234-5678')->set({'ShippedOn' => undef });
    $Shop->path('TestCustomer/Orders/1234-5678')->set({'ShippedOn' => $Now });
    $self->_cAssertItemCount(1, $Profile, $Now);
}


sub testOrderChange {
    my $self = shift;

    my $Shop = $self->shop;
    my $Now = GetCurrentDateTime();

    # test set
    my $Profile = $self->_initProfile('OrderChange');
    $self->_cAssertItemCount(0, $Profile, $Now);
    $Shop->path('TestCustomer/Orders/1234-5678')->set({'CustomerComment' => 'data' });
    $self->_cAssertItemCount(1, $Profile, $Now);

    # test unset
    $Profile = $self->_initProfile('OrderChange');
    $Shop->path('TestCustomer/Orders/1234-5678')->set({'CustomerComment' => undef });
    $self->_cAssertItemCount(1, $Profile, $Now);
}


sub init {
    my $self = shift;

    $self->SUPER::init;
    die 'Shop alias is not TestShop' unless $self->shop->alias eq 'TestShop';

    note 'importing import.xml';
    ImportObjects('import.xml', $self->shop->parent->pathString);
}

sub test {
    my $self = shift;
    $self->testStatus;
    $self->testOrderChange;
}

__PACKAGE__->runScript;
