#========================================================================================
# package      DE_EPAGES::Order::t::unit::OrderPatch
# base         DE_EPAGES::Core::API::Test
# state        public
#----------------------------------------------------------------------------------------
# description  Unit test for DE_EPAGES::Order::API::OrderPatch
#========================================================================================
package DE_EPAGES::Order::t::unit::OrderPatch;
use base DE_EPAGES::Core::API::Test;

use DE_EPAGES::Test::Mock::MockifyEpagesObject;
use DE_EPAGES::Test::Mock::Mockify qw (GetParametersFromMockifyCall WasCalled);
use DE_EPAGES::Test::Mock::Mockery;
use Test::More;

use strict;

my $LanguageID = 2; # language id of english



sub test {
    my $self = shift;

    $self->test_add_orderNumber();

    $self->test_add_customerComment();
    $self->test_add_internalNote();

    $self->test_add_billingAddress();
    $self->test_add_shippingAddress();

    $self->test_add_viewedOn();
    $self->test_add_rejectedOn();
    $self->test_add_inProcessOn();
    $self->test_add_pendingOn();
    $self->test_add_readyForDispatchOn();
    $self->test_add_partialyDispatchedOn();
    $self->test_add_dispatchedOn();
    $self->test_add_deliveredOn();
    $self->test_add_partialyInvoicedOn();
    $self->test_add_invoicedOn();
    $self->test_add_partialyPaidOn();
    $self->test_add_paidOn();
    $self->test_add_returnedOn();
    $self->test_add_closedOn();
    $self->test_add_archivedOn();


    $self->test_remove_customerComment();
    $self->test_remove_internalNote();

    $self->test_remove_viewedOn();
    $self->test_remove_rejectedOn();
    $self->test_remove_inProcessOn();
    $self->test_remove_pendingOn();
    $self->test_remove_readyForDispatchOn();
    $self->test_remove_partialyDispatchedOn();
    $self->test_remove_dispatchedOn();
    $self->test_remove_deliveredOn();
    $self->test_remove_partialyInvoicedOn();
    $self->test_remove_invoicedOn();
    $self->test_remove_partialyPaidOn();
    $self->test_remove_paidOn();
    $self->test_remove_returnedOn();
    $self->test_remove_closedOn();
    $self->test_remove_archivedOn();

    done_testing();
}



sub test_add_orderNumber {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $Mockery = $self->_createMocks();
    my $Order = $Mockery->get('Order');
    my $OrderPatch = $Mockery->get('OrderPatch');

    my $hPatchOperation = {
        'op' => 'add',
        'path' => '/orderNumber',
        'value' => 'order-12345',
    };

    $OrderPatch->patch($hPatchOperation);

    is($Order->alias(), 'order-12345', "$SubTestName - test if the attribute orderNumber was set.");
}



sub test_add_customerComment {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $Mockery = $self->_createMocks();
    my $Order = $Mockery->get('Order');
    my $OrderPatch = $Mockery->get('OrderPatch');

    my $hPatchOperation = {
        'op' => 'add',
        'path' => '/customerComment',
        'value' => 'a customer comment',
    };

    $OrderPatch->patch($hPatchOperation);

    is($Order->get('CustomerComment'), 'a customer comment', "$SubTestName - test if the attribute customerComment was set.");
}



sub test_add_internalNote {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $Mockery = $self->_createMocks();
    my $Order = $Mockery->get('Order');
    my $OrderPatch = $Mockery->get('OrderPatch');

    my $hPatchOperation = {
        'op' => 'add',
        'path' => '/internalNote',
        'value' => 'some internal notes',
    };

    $OrderPatch->patch($hPatchOperation);

    is($Order->get('Comment'), 'some internal notes', "$SubTestName - test if the attribute internalNote was set.");
}



sub test_add_billingAddress {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $Mockery = $self->_createMocks();
    my $OrderPatch = $Mockery->get('OrderPatch');

    my $hPatchOperation = {
        'op' => 'add',
        'path' => '/billingAddress',
        'value' => {
            'company'       => 'Test GmbH',
            'firstName'     => 'Joe',
            'lastName'      => 'Tester',
            'street'        => '123 Test St.',
            'streetDetails' => 'end of the street',
            'zipCode'       => '12345',
            'city'          => 'Testburg',
            'state'         => 'TST',
            'title'         => 'Test Engineer',
            'emailAddress'  => 'me@testing.org',
            'vatId'         => 'vat soll das',
            'salutation'    => 'Salve!',
        },
    };

    $OrderPatch->patch($hPatchOperation);

    my $SoapOrderService = $Mockery->get('SoapOrderService');
    my $aSetAddressArguments = GetParametersFromMockifyCall($SoapOrderService, 'setAddress');

    my $hAddressData = $aSetAddressArguments->[1];
    my $hExpectedAddressData = $self->_getExpectedAddressData();
    is_deeply($hAddressData, $hExpectedAddressData, "$SubTestName - test if the expected address data was used.");
    my $AddressType = $aSetAddressArguments->[2];
    is($AddressType, 'BillingAddress', "$SubTestName - test if the address type was billing.");

    my $Order = $Mockery->get('Order');
    my $OrderWasCalled = WasCalled($Order, 'setUpdated');
    is($OrderWasCalled, 1, "set updated was called!");
}



sub test_add_shippingAddress {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $Mockery = $self->_createMocks();
    my $OrderPatch = $Mockery->get('OrderPatch');

    my $hPatchOperation = {
        'op' => 'add',
        'path' => '/shippingAddress',
        'value' => {
            'company'       => 'Test GmbH',
            'firstName'     => 'Joe',
            'lastName'      => 'Tester',
            'street'        => '123 Test St.',
            'streetDetails' => 'end of the street',
            'zipCode'       => '12345',
            'city'          => 'Testburg',
            'state'         => 'TST',
            'title'         => 'Test Engineer',
            'emailAddress'  => 'me@testing.org',
            'vatId'         => 'vat soll das',
            'salutation'    => 'Salve!',
        },
    };

    $OrderPatch->patch($hPatchOperation);

    my $SoapOrderService = $Mockery->get('SoapOrderService');
    my $aSetAddressArguments = GetParametersFromMockifyCall($SoapOrderService, 'setAddress');

    my $hAddressData = $aSetAddressArguments->[1];
    my $hExpectedAddressData = $self->_getExpectedAddressData();
    is_deeply($hAddressData, $hExpectedAddressData, "$SubTestName - test if the expected address data was used.");
    my $AddressType = $aSetAddressArguments->[2];
    is($AddressType, 'ShippingAddress', "$SubTestName - test if the address type was shipping.");


    my $Order = $Mockery->get('Order');
    my $OrderWasCalled = WasCalled($Order, 'setUpdated');
    is($OrderWasCalled, 1, "set updated was called!");
}



sub test_add_viewedOn {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $Mockery = $self->_createMocks();
    my $Order = $Mockery->get('Order');
    my $OrderPatch = $Mockery->get('OrderPatch');

    my $hPatchOperation = {
        'op' => 'add',
        'path' => '/viewedOn',
        'value' => '2016-01-25T14:52:03.000Z',
    };

    $OrderPatch->patch($hPatchOperation);

    is($Order->get('ViewedOn'), '2016-01-25T14:52:03', "$SubTestName - test if the attribute viewedOn was set.");
}



sub test_add_rejectedOn {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $Mockery = $self->_createMocks();
    my $Order = $Mockery->get('Order');
    my $OrderPatch = $Mockery->get('OrderPatch');

    my $hPatchOperation = {
        'op' => 'add',
        'path' => '/rejectedOn',
        'value' => '2016-02-01T18:13:55.000Z',
    };

    $OrderPatch->patch($hPatchOperation);

    is($Order->get('CancelledOn'), '2016-02-01T18:13:55', "$SubTestName - test if the attribute rejectedOn was set.");
}



sub test_add_inProcessOn {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $Mockery = $self->_createMocks();
    my $Order = $Mockery->get('Order');
    my $OrderPatch = $Mockery->get('OrderPatch');

    my $hPatchOperation = {
        'op' => 'add',
        'path' => '/inProcessOn',
        'value' => '2016-02-03T04:14:23.000Z',
    };

    $OrderPatch->patch($hPatchOperation);

    is($Order->get('InProcessOn'), '2016-02-03T04:14:23', "$SubTestName - test if the attribute inProcessOn was set.");
}



sub test_add_pendingOn {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $Mockery = $self->_createMocks();
    my $Order = $Mockery->get('Order');
    my $OrderPatch = $Mockery->get('OrderPatch');

    my $hPatchOperation = {
        'op' => 'add',
        'path' => '/pendingOn',
        'value' => '2016-01-07T17:18:27.000Z',
    };

    $OrderPatch->patch($hPatchOperation);

    is($Order->get('PendingOn'), '2016-01-07T17:18:27', "$SubTestName - test if the attribute pendingOn was set.");
}



sub test_add_readyForDispatchOn {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $Mockery = $self->_createMocks();
    my $Order = $Mockery->get('Order');
    my $OrderPatch = $Mockery->get('OrderPatch');

    my $hPatchOperation = {
        'op' => 'add',
        'path' => '/readyForDispatchOn',
        'value' => '2015-11-17T16:35:43.000Z',
    };

    $OrderPatch->patch($hPatchOperation);

    is($Order->get('ReadyForShippingOn'), '2015-11-17T16:35:43', "$SubTestName - test if the attribute readyForDispatchOn was set.");
}



sub test_add_partialyDispatchedOn {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $Mockery = $self->_createMocks();
    my $Order = $Mockery->get('Order');
    my $OrderPatch = $Mockery->get('OrderPatch');

    my $hPatchOperation = {
        'op' => 'add',
        'path' => '/partialyDispatchedOn',
        'value' => '2015-05-13T14:21:44.000Z',
    };

    $OrderPatch->patch($hPatchOperation);

    is($Order->get('PartlyDispatchedOn'), '2015-05-13T14:21:44', "$SubTestName - test if the attribute partialyDispatchedOn was set.");
}



sub test_add_dispatchedOn {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $Mockery = $self->_createMocks();
    my $Order = $Mockery->get('Order');
    my $OrderPatch = $Mockery->get('OrderPatch');

    my $hPatchOperation = {
        'op' => 'add',
        'path' => '/dispatchedOn',
        'value' => '2015-07-17T11:33:52.000Z',
    };

    $OrderPatch->patch($hPatchOperation);

    is($Order->get('DispatchedOn'), '2015-07-17T11:33:52', "$SubTestName - test if the attribute dispatchedOn was set.");
}



sub test_add_deliveredOn {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $Mockery = $self->_createMocks();
    my $Order = $Mockery->get('Order');
    my $OrderPatch = $Mockery->get('OrderPatch');

    my $hPatchOperation = {
        'op' => 'add',
        'path' => '/deliveredOn',
        'value' => '2015-11-29T13:12:44.000Z',
    };

    $OrderPatch->patch($hPatchOperation);

    is($Order->get('ShippedOn'), '2015-11-29T13:12:44', "$SubTestName - test if the attribute deliveredOn was set.");
}



sub test_add_partialyInvoicedOn {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $Mockery = $self->_createMocks();
    my $Order = $Mockery->get('Order');
    my $OrderPatch = $Mockery->get('OrderPatch');

    my $hPatchOperation = {
        'op' => 'add',
        'path' => '/partialyInvoicedOn',
        'value' => '2015-09-12T16:23:05.000Z',
    };

    $OrderPatch->patch($hPatchOperation);

    is($Order->get('PartlyInvoicedOn'), '2015-09-12T16:23:05', "$SubTestName - test if the attribute partialyInvoicedOn was set.");
}



sub test_add_invoicedOn {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $Mockery = $self->_createMocks();
    my $Order = $Mockery->get('Order');
    my $OrderPatch = $Mockery->get('OrderPatch');

    my $hPatchOperation = {
        'op' => 'add',
        'path' => '/invoicedOn',
        'value' => '2015-11-22T11:26:45.000Z',
    };

    $OrderPatch->patch($hPatchOperation);

    is($Order->get('InvoicedOn'), '2015-11-22T11:26:45', "$SubTestName - test if the attribute invoicedOn was set.");
}



sub test_add_partialyPaidOn {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $Mockery = $self->_createMocks();
    my $Order = $Mockery->get('Order');
    my $OrderPatch = $Mockery->get('OrderPatch');

    my $hPatchOperation = {
        'op' => 'add',
        'path' => '/partialyPaidOn',
        'value' => '2015-08-30T10:36:54.000Z',
    };

    $OrderPatch->patch($hPatchOperation);

    is($Order->get('PartlyPaidOn'), '2015-08-30T10:36:54', "$SubTestName - test if the attribute partialyPaidOn was set.");
}



sub test_add_paidOn {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $Mockery = $self->_createMocks();
    my $Order = $Mockery->get('Order');
    my $OrderPatch = $Mockery->get('OrderPatch');

    my $hPatchOperation = {
        'op' => 'add',
        'path' => '/paidOn',
        'value' => '2016-01-12T14:55:22.000Z',
    };

    $OrderPatch->patch($hPatchOperation);

    is($Order->get('PaidOn'), '2016-01-12T14:55:22', "$SubTestName - test if the attribute paidOn was set.");
}



sub test_add_returnedOn {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $Mockery = $self->_createMocks();
    my $Order = $Mockery->get('Order');
    my $OrderPatch = $Mockery->get('OrderPatch');

    my $hPatchOperation = {
        'op' => 'add',
        'path' => '/returnedOn',
        'value' => '2015-05-02T05:42:25.000Z',
    };

    $OrderPatch->patch($hPatchOperation);

    is($Order->get('ReturnedOn'), '2015-05-02T05:42:25', "$SubTestName - test if the attribute returnedOn was set.");
}



sub test_add_closedOn {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $Mockery = $self->_createMocks();
    my $Order = $Mockery->get('Order');
    my $OrderPatch = $Mockery->get('OrderPatch');

    my $hPatchOperation = {
        'op' => 'add',
        'path' => '/closedOn',
        'value' => '2015-12-06T09:33:46.000Z',
    };

    $OrderPatch->patch($hPatchOperation);

    is($Order->get('ClosedOn'), '2015-12-06T09:33:46', "$SubTestName - test if the attribute closedOn was set.");
}



sub test_add_archivedOn {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $Mockery = $self->_createMocks();
    my $Order = $Mockery->get('Order');
    my $OrderPatch = $Mockery->get('OrderPatch');

    my $hPatchOperation = {
        'op' => 'add',
        'path' => '/archivedOn',
        'value' => '2015-05-25T23:18:17.000Z',
    };

    $OrderPatch->patch($hPatchOperation);

    is($Order->get('ArchivedOn'), '2015-05-25T23:18:17', "$SubTestName - test if the attribute archivedOn was set.");
}



sub test_remove_customerComment {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $Mockery = $self->_createMocks();
    my $Order = $Mockery->get('Order');
    my $OrderPatch = $Mockery->get('OrderPatch');

    my $hPatchOperation = {
        'op' => 'remove',
        'path' => '/customerComment',
    };

    $OrderPatch->patch($hPatchOperation);

    is($Order->get('CustomerComment'), undef, "$SubTestName - test if the attribute customerComment was removed.");
}



sub test_remove_internalNote {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $Mockery = $self->_createMocks();
    my $Order = $Mockery->get('Order');
    my $OrderPatch = $Mockery->get('OrderPatch');

    my $hPatchOperation = {
        'op' => 'remove',
        'path' => '/internalNote',
    };

    $OrderPatch->patch($hPatchOperation);

    is($Order->get('Comment'), undef, "$SubTestName - test if the attribute internalNote was removed.");
}



sub test_remove_viewedOn {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $Mockery = $self->_createMocks();
    my $Order = $Mockery->get('Order');
    my $OrderPatch = $Mockery->get('OrderPatch');

    my $hPatchOperation = {
        'op' => 'remove',
        'path' => '/viewedOn',
    };

    $OrderPatch->patch($hPatchOperation);

    is($Order->get('ViewedOn'), undef, "$SubTestName - test if the attribute viewedOn was removed.");
}



sub test_remove_rejectedOn {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $Mockery = $self->_createMocks();
    my $Order = $Mockery->get('Order');
    my $OrderPatch = $Mockery->get('OrderPatch');

    my $hPatchOperation = {
        'op' => 'remove',
        'path' => '/rejectedOn',
    };

    $OrderPatch->patch($hPatchOperation);

    is($Order->get('CancelledOn'), undef, "$SubTestName - test if the attribute rejectedOn was removed.");
}



sub test_remove_inProcessOn {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $Mockery = $self->_createMocks();
    my $Order = $Mockery->get('Order');
    my $OrderPatch = $Mockery->get('OrderPatch');

    my $hPatchOperation = {
        'op' => 'remove',
        'path' => '/inProcessOn',
    };

    $OrderPatch->patch($hPatchOperation);

    is($Order->get('InProcessOn'), undef, "$SubTestName - test if the attribute inProcessOn was removed.");
}



sub test_remove_pendingOn {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $Mockery = $self->_createMocks();
    my $Order = $Mockery->get('Order');
    my $OrderPatch = $Mockery->get('OrderPatch');

    my $hPatchOperation = {
        'op' => 'remove',
        'path' => '/pendingOn',
    };

    $OrderPatch->patch($hPatchOperation);

    is($Order->get('PendingOn'), undef, "$SubTestName - test if the attribute pendingOn was removed.");
}



sub test_remove_readyForDispatchOn {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $Mockery = $self->_createMocks();
    my $Order = $Mockery->get('Order');
    my $OrderPatch = $Mockery->get('OrderPatch');

    my $hPatchOperation = {
        'op' => 'remove',
        'path' => '/readyForDispatchOn',
    };

    $OrderPatch->patch($hPatchOperation);

    is($Order->get('ReadyForShippingOn'), undef, "$SubTestName - test if the attribute readyForDispatchOn was removed.");
}



sub test_remove_partialyDispatchedOn {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $Mockery = $self->_createMocks();
    my $Order = $Mockery->get('Order');
    my $OrderPatch = $Mockery->get('OrderPatch');

    my $hPatchOperation = {
        'op' => 'remove',
        'path' => '/partialyDispatchedOn',
    };

    $OrderPatch->patch($hPatchOperation);

    is($Order->get('PartlyDispatchedOn'), undef, "$SubTestName - test if the attribute partialyDispatchedOn was removed.");
}



sub test_remove_dispatchedOn {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $Mockery = $self->_createMocks();
    my $Order = $Mockery->get('Order');
    my $OrderPatch = $Mockery->get('OrderPatch');

    my $hPatchOperation = {
        'op' => 'remove',
        'path' => '/dispatchedOn',
    };

    $OrderPatch->patch($hPatchOperation);

    is($Order->get('DispatchedOn'), undef, "$SubTestName - test if the attribute dispatchedOn was removed.");
}



sub test_remove_deliveredOn {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $Mockery = $self->_createMocks();
    my $Order = $Mockery->get('Order');
    my $OrderPatch = $Mockery->get('OrderPatch');

    my $hPatchOperation = {
        'op' => 'remove',
        'path' => '/deliveredOn',
    };

    $OrderPatch->patch($hPatchOperation);

    is($Order->get('ShippedOn'), undef, "$SubTestName - test if the attribute deliveredOn was removed.");
}



sub test_remove_partialyInvoicedOn {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $Mockery = $self->_createMocks();
    my $Order = $Mockery->get('Order');
    my $OrderPatch = $Mockery->get('OrderPatch');

    my $hPatchOperation = {
        'op' => 'remove',
        'path' => '/partialyInvoicedOn',
    };

    $OrderPatch->patch($hPatchOperation);

    is($Order->get('PartlyInvoicedOn'), undef, "$SubTestName - test if the attribute partialyInvoicedOn was removed.");
}



sub test_remove_invoicedOn {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $Mockery = $self->_createMocks();
    my $Order = $Mockery->get('Order');
    my $OrderPatch = $Mockery->get('OrderPatch');

    my $hPatchOperation = {
        'op' => 'remove',
        'path' => '/invoicedOn',
    };

    $OrderPatch->patch($hPatchOperation);

    is($Order->get('InvoicedOn'), undef, "$SubTestName - test if the attribute invoicedOn was removed.");
}



sub test_remove_partialyPaidOn {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $Mockery = $self->_createMocks();
    my $Order = $Mockery->get('Order');
    my $OrderPatch = $Mockery->get('OrderPatch');

    my $hPatchOperation = {
        'op' => 'remove',
        'path' => '/partialyPaidOn',
    };

    $OrderPatch->patch($hPatchOperation);

    is($Order->get('PartlyPaidOn'), undef, "$SubTestName - test if the attribute partialyPaidOn was removed.");
}



sub test_remove_paidOn {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $Mockery = $self->_createMocks();
    my $Order = $Mockery->get('Order');
    my $OrderPatch = $Mockery->get('OrderPatch');

    my $hPatchOperation = {
        'op' => 'remove',
        'path' => '/paidOn',
    };

    $OrderPatch->patch($hPatchOperation);

    is($Order->get('PaidOn'), undef, "$SubTestName - test if the attribute paidOn was removed.");
}



sub test_remove_returnedOn {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $Mockery = $self->_createMocks();
    my $Order = $Mockery->get('Order');
    my $OrderPatch = $Mockery->get('OrderPatch');

    my $hPatchOperation = {
        'op' => 'remove',
        'path' => '/returnedOn',
    };

    $OrderPatch->patch($hPatchOperation);

    is($Order->get('ReturnedOn'), undef, "$SubTestName - test if the attribute returnedOn was removed.");
}



sub test_remove_closedOn {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $Mockery = $self->_createMocks();
    my $Order = $Mockery->get('Order');
    my $OrderPatch = $Mockery->get('OrderPatch');

    my $hPatchOperation = {
        'op' => 'remove',
        'path' => '/closedOn',
    };

    $OrderPatch->patch($hPatchOperation);

    is($Order->get('ClosedOn'), undef, "$SubTestName - test if the attribute closedOn was removed.");
}



sub test_remove_archivedOn {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $Mockery = $self->_createMocks();
    my $Order = $Mockery->get('Order');
    my $OrderPatch = $Mockery->get('OrderPatch');

    my $hPatchOperation = {
        'op' => 'remove',
        'path' => '/archivedOn',
    };

    $OrderPatch->patch($hPatchOperation);

    is($Order->get('ArchivedOn'), undef, "$SubTestName - test if the attribute archivedOn was removed.");
}



sub _createMocks {
    my $self = shift;
    my ($LanguageId, $CurrencyId_) = @_;

    my $Mockery = DE_EPAGES::Test::Mock::Mockery->new();

    $Mockery->register('OrderPatch', ['Order', 'SoapOrderService'], sub {
        my ($Order, $SoapOrderService) = @_;
        my $Mockify = DE_EPAGES::Test::Mock::Mockify->new('DE_EPAGES::Order::API::OrderPatch', [$Order, $LanguageId]);
        $Mockify->addMockWithReturnValue('_createSoapOrderService', $SoapOrderService);
        $Mockify->addMockWithReturnValue('_getLastUpdateOrderChangeProfile', $Mockify->getMockObject());
        return $Mockify->getMockObject();
    });

    $Mockery->register('Shop', [], sub {
        my $Mockify = DE_EPAGES::Test::Mock::MockifyEpagesObject->new('DE_EPAGES::Shop::API::Object::Shop', {
            'TaxModel' => 1,
        });
        return $Mockify->getMockObject();
    });

    $Mockery->register('Order', ['Shop'], sub {
        my ($Shop) = @_;
        my $Mockify = DE_EPAGES::Test::Mock::MockifyEpagesObject->new('DE_EPAGES::Order::API::Object::CustomerOrder', {
            'Site' => $Shop,
        });
        $Mockify->addMockWithReturnValueAndParameterCheck('setUpdated', undef, ['object']);
        return $Mockify->getMockObject();
    });

    $Mockery->register('SoapOrderService', [], sub {
        my $hOptions = {'Object' => 1}; # If no options hash with an object was provided, OrderService->new() will load the root object.
        my $Mockify = DE_EPAGES::Test::Mock::Mockify->new('DE_EPAGES::Order::API::WebService::OrderService', [%$hOptions]);
        $Mockify->addMockWithReturnValueAndParameterCheck('setAddress', undef, ['object', 'hashref', 'string']);
        return $Mockify->getMockObject();
    });

    return $Mockery->assemble();
}



sub _getExpectedAddressData {
    return {
        'Street2' => 'end of the street',
        'FirstName' => 'Joe',
        'Street' => '123 Test St.',
        'City' => 'Testburg',
        'State' => 'TST',
        'Salutation' => 'Salve!',
        'Title' => 'Test Engineer',
        'CountryID' => undef,
        'Zipcode' => '12345',
        'VATID' => 'vat soll das',
        'LastName' => 'Tester',
        'Birthday' => undef,
        'EMail' => 'me@testing.org',
        'Company' => 'Test GmbH',
    };
}

__PACKAGE__->runScript();